@@ -60,6 +60,8 @@ sub _new {
 	} else {
 	    die "UUID must be either 16 unsigned bytes, or 32/36 hex characters long";
 	}
+    } elsif (exists $params{volume}) {
+	$self = Sys::Virt::StoragePool::_lookup_by_volume($params{volume});
     } elsif (exists $params{xml}) {
 	if ($params{nocreate}) {
 	    $self = Sys::Virt::StoragePool::_define_xml($con,  $params{xml});
@@ -150,10 +152,10 @@ and if omitted defaults to zero.
 Delete the storage pool. The C<$flags> parameter allows the data to
 be optionally wiped during delete and if omitted defaults to zero.
 
-=item %info = $pool->get_info()
+=item $info = $pool->get_info()
 
 Retrieve information about the current storage pool state. The
-returned hash has the following keys
+returned hash reference has the following keys
 
 =over 4
 
@@ -187,11 +189,13 @@ can be used as the C<maxnames> parameter to C<list_storage_vol_names>.
 Return a list of all volume names in this storage pool. The names can
 be used with the C<get_volume_by_name> method.
 
-=item my @nets = $pool->list_volumes()
+=item my @vols = $pool->list_volumes()
 
 Return a list of all volumes in the storage pool.
 The elements in the returned list are instances of the
-L<Sys::Virt::StorageVol> class.
+L<Sys::Virt::StorageVol> class. This method requires O(n)
+RPC calls, so the C<list_all_volumes> method is
+recommended as a more efficient alternative.
 
 =cut
 
@@ -207,13 +211,20 @@ sub list_volumes {
 	    push @volumes, Sys::Virt::StorageVol->_new(pool => $self, name => $name);
 	};
 	if ($@) {
-	    # nada - domain went away before we could look it up
+	    # nada - volume went away before we could look it up
 	};
     }
     return @volumes;
 }
 
 
+=item my @volumes = $pool->list_all_volumes($flags)
+
+Return a list of all storage volumes associated with this pool.
+The elements in the returned list are instances of the
+L<Sys::Virt::StorageVol> class. The C<$flags> parameter can be
+used to filter the list of return storage volumes.
+
 =item my $vol = $pool->get_volume_by_name($name)
 
 Return the volume with a name of C<$name>. The returned object is
@@ -296,6 +307,10 @@ The storage pool is running and can be queried for volumes
 The storage pool is running, but its operation is degraded due
 to a failure.
 
+=item Sys::Virt::StoragePool::STATE_INACCESSIBLE
+
+The storage pool is not currently accessible
+
 =back
 
 =head2 DELETION MODES
@@ -340,6 +355,96 @@ Overwrite existing storage pool data
 
 =back
 
+=head2 XML DOCUMENTS
+
+The following constants are useful when requesting
+XML for storage pools
+
+=over 4
+
+=item Sys::Virt::StoragePool::XML_INACTIVE
+
+Return XML describing the inactive state of the storage
+pool.
+
+=back
+
+=head1 LIST FILTERING
+
+The following constants are used to filter object lists
+
+=over 4
+
+=item Sys::Virt::StoragePool::LIST_ACTIVE
+
+Include storage pools which are active
+
+=item Sys::Virt::StoragePool::LIST_INACTIVE
+
+Include storage pools which are inactive
+
+=item Sys::Virt::StoragePool::LIST_AUTOSTART
+
+Include storage pools which are marked for autostart
+
+=item Sys::Virt::StoragePool::LIST_NO_AUTOSTART
+
+Include storage pools which are not marked for autostart
+
+=item Sys::Virt::StoragePool::LIST_PERSISTENT
+
+Include storage pools which are persistent
+
+=item Sys::Virt::StoragePool::LIST_TRANSIENT
+
+Include storage pools which are transient
+
+=item Sys::Virt::StoragePool::LIST_DIR
+
+Include directory storage pools
+
+=item Sys::Virt::StoragePool::LIST_DISK
+
+Include disk storage pools
+
+=item Sys::Virt::StoragePool::LIST_FS
+
+Include filesytem storage pools
+
+=item Sys::Virt::StoragePool::LIST_ISCSI
+
+Include iSCSI storage pools
+
+=item Sys::Virt::StoragePool::LIST_LOGICAL
+
+Include LVM storage pools
+
+=item Sys::Virt::StoragePool::LIST_MPATH
+
+Include multipath storage pools
+
+=item Sys::Virt::StoragePool::LIST_NETFS
+
+Include network filesystem storage pools
+
+=item Sys::Virt::StoragePool::LIST_RBD
+
+Include RBD storage pools
+
+=item Sys::Virt::StoragePool::LIST_SCSI
+
+Include SCSI storage pools
+
+=item Sys::Virt::StoragePool::LIST_SHEEPDOG
+
+Include sheepdog storage pools
+
+=item Sys::Virt::StoragePool::LIST_GLUSTER
+
+Include gluster storage pools
+
+=back
+
 =head1 AUTHORS
 
 Daniel P. Berrange <berrange@redhat.com>
